@@ -17,12 +17,13 @@
 #' @export
 setMethod("colAnyMissings", "DelayedMatrix",
           function(x, rows = NULL, cols = NULL, force_block_processing = FALSE,
-                   ...) {
+                   ..., useNames = NA) {
             colAnyNAs(x = x,
                     rows = rows,
                     cols = cols,
                     force_block_processing = force_block_processing,
-                    ...)
+                    ...,
+                    useNames = useNames)
           }
 )
 
@@ -31,4 +32,12 @@ setMethod("colAnyMissings", "DelayedMatrix",
 #
 
 #' @export
-setMethod("colAnyMissings", "matrix", matrixStats::colAnyMissings)
+setMethod("colAnyMissings", "matrix",
+          function(x, rows = NULL, cols = NULL, ..., useNames = NA) {
+            colAnyNAs(x = x,
+                      rows = rows,
+                      cols = cols,
+                      ...,
+                      useNames = useNames)
+          }
+)
